# -*- coding: utf-8 -*-
"""
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
# Core
Package | `__init__.py`

Daniel Bakas Amuchastegui\
March 16, 2020

Copyright © Semantyk 2020. All rights reserved.\
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
"""

from . import graph, identifier, namespace, node
from .graph import *
from .identifier import *
from .namespace import *
from .node import *
